@@ -1,4 +1,4 @@
-from . import approxinterp
+from nummethvera.approxinterp import *
 from . import diffequat
 from . import diffintegr
 from . import matrixop
@@ -6,8 +6,8 @@ from . import otjigants
 from . import slau
 from . import veivletfurie
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 __all__ = """
-    approxinterp.read_csv
-    approxinterp.polinom_chebyshev
+    read_csv
+    polinom_chebyshev
     """.split()
